@@ -58,7 +58,8 @@
      STRINGDEF = 274,
      REGEXPNOPREPROC = 275,
      VARUSE = 276,
-     REGEXPDEF = 277
+     BACKREFVAR = 277,
+     REGEXPDEF = 278
    };
 #endif
 /* Tokens.  */
@@ -81,7 +82,8 @@
 #define STRINGDEF 274
 #define REGEXPNOPREPROC 275
 #define VARUSE 276
-#define REGEXPDEF 277
+#define BACKREFVAR 277
+#define REGEXPDEF 278
 
 
 
@@ -105,7 +107,7 @@ typedef union YYSTYPE
   int flag ;
 }
 /* Line 1489 of yacc.c.  */
-#line 109 "langdefparser.h"
+#line 111 "langdefparser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
