@@ -4,6 +4,8 @@
 
 #include "statelangelem.h"
 
+#include "namedsubexpslangelem.h"
+
 #include "delimitedlangelem.h"
 
 #include "langelems.h"
@@ -42,6 +44,12 @@ LangElems::dispatch_build(RegExpStateBuilder *RegExpStateBuilder_o, RegExpStateP
   RegExpStateBuilder_o->_forward_build(this, state);
 }
 
+void
+NamedSubExpsLangElem::dispatch_build(RegExpStateBuilder *RegExpStateBuilder_o, RegExpStatePointer state)
+{
+  RegExpStateBuilder_o->_forward_build(this, state);
+}
+
 void
 StateLangElem::dispatch_build(RegExpStateBuilder *RegExpStateBuilder_o, RegExpStatePointer state)
 {
